==> BCWipe-1.2-3.tar.gz: bcwipe/wipe.h <==
/*******************************************************************
 *  Copyright (c) 1994-2002 Jetico, Inc., Finland
 *  All rights reserved.
 *
 *  File:          wipe.h
 *
 *  Description:   BestCrypt wipe utility
 *
 *  Author:        Vitaliy Zolotarev
 *
 *  Created:       20-Nov-1999
 *
 *  Revision:      $Id: wipe.h,v 1.5 2002/12/11 06:42:11 crypt Rel-1.2-3 $ 
 *
 *
 *******************************************************************/

#ifndef _WIPE_H_
#define _WIPE_H_

#define VERSION     "1.2"

#define TRUE        1
#define FALSE       0

#define OK          0
#define ERROR       -1

#define DPASSES     35
#define QPASSES     7

#define BUFFSIZE    64*1024

#define NAME_MAX_PASSES 10
#define NAME_TRIES      200

#define OPTSTRING   "Vhvrfm:dbIiSsp"

int o_verbose      = FALSE; /* -v,  */
int o_recurse      = FALSE; /* -r, */
int o_force        = FALSE; /* -f, */
int o_pas_num      = DPASSES;/*-n, number of passes */
int o_dont_delete  = FALSE; /* -d, do not delete files after wiping */
int o_wipe_dev     = FALSE; /* -b, wipe devices */
int o_interactive  = TRUE;  /* -i, ask confirmation for wiping, -I disable interactive */
int o_use_DoD      = FALSE; /* -q and -n switch on using DoD standart */
int o_use_rand     = FALSE; /* -s, use system random instead of SHA-1 */
int o_use_buff     = FALSE; /* -p, use 64Kb random buffer instead of full random */
int o_dont_wipe_fn = FALSE; /* -D, do not wipe file names */
int o_wipe_slacks  = FALSE; /* -S, wipe file slacks */
char *o_user_file  = NULL;  /* -u, user defined patterns (filename) */

struct pass_s {
    int len;                /* if len==0 use random */
    char *pat;
} pg_pass[] = {
    { 0, 0,             },  /* 1  random */
    { 0, 0,             },  /* 2  random */
    { 0, 0,             },  /* 3  random */
    { 0, 0,             },  /* 4  random */
    { 1, "\x55",        },  /* 5  RLL MFM */
    { 1, "\xaa",        },  /* 6  RLL MFM */
    { 3, "\x92\x49\x24",},  /* 7  RLL MFM */
    { 3, "\x49\x24\x92",},  /* 8  RLL MFM */
    { 3, "\x24\x92\x49",},  /* 9  RLL MFM */
    { 1, "\x00",        },  /* 10 RLL */
    { 1, "\x11",        },  /* 11 RLL */
    { 1, "\x22",        },  /* 12 RLL */
    { 1, "\x33",        },  /* 13 RLL */
    { 1, "\x44",        },  /* 14 RLL */
    { 1, "\x55",        },  /* 15 RLL */
    { 1, "\x66",        },  /* 16 RLL */
    { 1, "\x77",        },  /* 17 RLL */
    { 1, "\x88",        },  /* 18 RLL */
    { 1, "\x99",        },  /* 19 RLL */
    { 1, "\xaa",        },  /* 20 RLL */
    { 1, "\xbb",        },  /* 21 RLL */
    { 1, "\xcc",        },  /* 22 RLL */
    { 1, "\xdd",        },  /* 23 RLL */
    { 1, "\xee",        },  /* 24 RLL */
    { 1, "\xff",        },  /* 25 RLL */
    { 3, "\x92\x49\x24",},  /* 26 RLL MFM */
    { 3, "\x49\x24\x92",},  /* 27 RLL MFM */
    { 3, "\x24\x92\x49",},  /* 28 RLL MFM */
    { 3, "\x6d\xb6\xdb",},  /* 29 RLL */
    { 3, "\xb6\xdb\x6d",},  /* 30 RLL */
    { 3, "\xdb\x6d\xb6",},  /* 31 RLL */
    { 0, 0,             },  /* 32 random */
    { 0, 0,             },  /* 33 random */
    { 0, 0,             },  /* 34 random */
    { 0, 0,             }   /* 35 random */
},dod_pass[] = {
    { 1, "\x35",        },  
    { 1, "\xca",        },  
    { 1, "\x97",        },  
    { 1, "\x68",        },  
    { 1, "\xac",        },  
    { 1, "\x53",        },  
    { 0, 0,             }   
};


char *usage_string=""
"Copyright 2002 Jetico, Inc.  \n"
"Usage: bcwipe [OPTIONS]... FILE...\n"
"Remove with wiping FILE(s).\n"
"\n"
"  -V       output version information and exit\n"
"  -md      U.S. DoD seven pass extended character rotation wiping *\n"
"  -mg      (default) is 35 pass wiping by Peter Gutmann           **\n"
"  -m n     U.S. DoD n pass extended character rotation wiping     *\n"
"  -s       use system random instead of SHA-1\n"
"  -p       use 64Kb random pattern instead of full random\n"
"  -v       explain what is being done\n"
"  -r       process the contents directories recursively\n"
"  -f       force wiping, never prompt        (use with caution)\n"
"  -d       do not delete file(s) after wiping\n"
"  -b       wipe contents of block devices    (use with caution)\n"
"  -S       wipe file slacks\n"
"  -i       prompt before any removal (y/[n]/a)\n"
"           y - yes, n - no(default), a - yes for all\n"
"  -I       disable interactive prompt\n"
"  -h       display this help and exit\n"
"\n"
"*    - U.S. DoD 5200.28 (Department of Defence)\n"
"**   - Secure Deletion of Data from Magnetic and Solid-State Memory\n"
"       http://www.cs.auckland.ac.nz/~pgut001/pubs/secure_del.html\n"  
"\n"
"Report bugs to support@jetico.com \n";

#endif  /* _WIPE_H_ */

==> BCWipe-1.6-1.tar.gz: bcwipe/wipe.h <==
/*******************************************************************
 *  Copyright (c) 1994-2002 Jetico, Inc., Finland
 *  All rights reserved.
 *
 *  File:          wipe.h
 *
 *  Description:   BestCrypt wipe utility
 *
 *  Author:        Vitaliy Zolotarev
 *
 *  Created:       20-Nov-1999
 *
 *  Revision:      $Id: wipe.h,v 1.13 2006/02/17 06:41:59 crypt Rel 1.6-1 $ 
 *
 *
 *******************************************************************/

#ifndef _WIPE_H_
#define _WIPE_H_

#define VERSION     "1.6"

#define TRUE        1
#define FALSE       0

#define OK          0
#define ERROR       -1

#define DPASSES     35
#define QPASSES     7

#define BUFFSIZE    1024*1024

#define NAME_MAX_PASSES 10
#define NAME_TRIES      200

#define OPTSTRING   "Vhvn:rfm:dbIiSspF"

int o_verbose      = FALSE; /* -v,  */
int o_recurse      = FALSE; /* -r, */
int o_force        = FALSE; /* -f, */
int o_pas_num      = DPASSES;
int o_dont_delete  = FALSE; /* -d, do not delete files after wiping */
int o_wipe_dev     = FALSE; /* -b, wipe devices */
int o_interactive  = TRUE;  /* -i, ask confirmation for wiping, -I disable interactive */
int o_use_DoD      = FALSE; /* -m d and -n switch on using DoD standart */
int o_use_rand     = FALSE; /* -s, use system random instead of SHA-1 */
int o_use_buff     = FALSE; /* -p, use 64Kb random buffer instead of full random */
int o_dont_wipe_fn = FALSE; /* -D, do not wipe file names */
int o_wipe_slacks  = FALSE; /* -S, wipe file slacks */
int o_wipe_free_space = FALSE; /* -F, wipe free space */
int o_nas_wiping   = FALSE; /*-n, NAS wiping */
int o_nas_delay    = 0;     /*-n, NAS wiping delay*/
char *o_user_file  = NULL;  /* -u, user defined patterns (filename) */
int o_use_zero     = FALSE; /* -m z */
int o_use_sector_number  = FALSE; /* -m t */

struct pass_s {
    int len;                /* if len==0 use random */
    char *pat;
} pg_pass[] = {
    { 0, 0,             },  /* 1  random */
    { 0, 0,             },  /* 2  random */
    { 0, 0,             },  /* 3  random */
    { 0, 0,             },  /* 4  random */
    { 1, "\x55",        },  /* 5  RLL MFM */
    { 1, "\xaa",        },  /* 6  RLL MFM */
    { 3, "\x92\x49\x24",},  /* 7  RLL MFM */
    { 3, "\x49\x24\x92",},  /* 8  RLL MFM */
    { 3, "\x24\x92\x49",},  /* 9  RLL MFM */
    { 1, "\x00",        },  /* 10 RLL */
    { 1, "\x11",        },  /* 11 RLL */
    { 1, "\x22",        },  /* 12 RLL */
    { 1, "\x33",        },  /* 13 RLL */
    { 1, "\x44",        },  /* 14 RLL */
    { 1, "\x55",        },  /* 15 RLL */
    { 1, "\x66",        },  /* 16 RLL */
    { 1, "\x77",        },  /* 17 RLL */
    { 1, "\x88",        },  /* 18 RLL */
    { 1, "\x99",        },  /* 19 RLL */
    { 1, "\xaa",        },  /* 20 RLL */
    { 1, "\xbb",        },  /* 21 RLL */
    { 1, "\xcc",        },  /* 22 RLL */
    { 1, "\xdd",        },  /* 23 RLL */
    { 1, "\xee",        },  /* 24 RLL */
    { 1, "\xff",        },  /* 25 RLL */
    { 3, "\x92\x49\x24",},  /* 26 RLL MFM */
    { 3, "\x49\x24\x92",},  /* 27 RLL MFM */
    { 3, "\x24\x92\x49",},  /* 28 RLL MFM */
    { 3, "\x6d\xb6\xdb",},  /* 29 RLL */
    { 3, "\xb6\xdb\x6d",},  /* 30 RLL */
    { 3, "\xdb\x6d\xb6",},  /* 31 RLL */
    { 0, 0,             },  /* 32 random */
    { 0, 0,             },  /* 33 random */
    { 0, 0,             },  /* 34 random */
    { 0, 0,             }   /* 35 random */
},dod_pass[] = {
    { 1, "\x35",        },  
    { 1, "\xca",        },  
    { 1, "\x97",        },  
    { 1, "\x68",        },  
    { 1, "\xac",        },  
    { 1, "\x53",        },  
    { 0, 0,             }   
};


char *usage_string=""
"Copyright 2006 Jetico, Inc.  \n"
"Usage: bcwipe [OPTIONS]... FILE...\n"
"Remove with wiping FILE(s).\n"
"\n"
"  -V       output version information and exit\n"
"  -md      U.S. DoD seven pass extended character rotation wiping *\n"
"  -mg      (default) is 35 pass wiping by Peter Gutmann           **\n"
"  -mt      One pass test mode. First 4 bytes of every 512 bytes block\n"
"             will contain block number\n"
"  -mz      One pass zero wiping\n"
"  -m n     U.S. DoD n pass extended character rotation wiping     *\n"
"  -n sec   Wait sec seconds between wiping passes. (NAS mode)     ***\n"
"  -s       use system random instead of SHA-1\n"
"  -p       use random pattern instead of full random\n"
"  -v       explain what is being done\n"
"  -r       process the contents directories recursively\n"
"  -f       force wiping, never prompt        (use with caution)\n"
"  -d       do not delete file(s) after wiping\n"
"  -b       wipe contents of block devices    (use with caution)\n"
"  -S       wipe file slacks\n"
"  -F       wipe free space\n"
"  -i       prompt before any removal (y/[n]/a)\n"
"             y - yes, n - no(default), a - yes for all\n"
"  -I       disable interactive prompt\n"
"  -h       display this help and exit\n"
"\n"
"*    - U.S. DoD 5200.28 (Department of Defence)\n"
"**   - Secure Deletion of Data from Magnetic and Solid-State Memory\n"
"       http://www.cs.auckland.ac.nz/~pgut001/pubs/secure_del.html\n"  
"***  - modern enterprise level storage systems (NAS, disk arrays etc.)\n"
"       employ powerful caches. To avoid undesirable caching effects\n"
"       use this option to insert delay between wiping passes.\n"
"\n"
"Report bugs to support@jetico.com \n";

#endif  /* _WIPE_H_ */
